import{d,eB as g,G as m,a as b,b as f,c as v,w as i,f as s}from"./outputWidgets.c4f3de67.js";import{B as _}from"./BaseLayout.3a885926.js";import{a as h}from"./asyncComputed.c75b06d6.js";import{P as y}from"./project.fda53dcc.js";import"./router.88734ca5.js";import{O as z}from"./organization.73e64f9c.js";import"./columns.aa61756c.js";import{_ as j}from"./Navbar.vue_vue_type_script_setup_true_lang.056998e5.js";import{S as I}from"./Sidebar.9ff7a5b4.js";import{y as w,z as B,A as k,B as C,C as P,q as $,D as x,E as D,u as M,v as O,x as S}from"./icons.49e74e71.js";import"./gateway.5578a098.js";import"./record.685c8ba7.js";import"./pubsub.1842fa2d.js";import"./Base.9ed9c296.js";import"./transButton.ebe60b80.js";import"./Text.fcf8f28f.js";import"./Title.345a4775.js";import"./index.db3809d7.js";import"./logo.084e5d7c.js";import"./index.205feec3.js";import"./Tooltip.48f63d67.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="754d480d-9f25-45fa-a138-92aaf14543a8",o._sentryDebugIdIdentifier="sentry-dbid-754d480d-9f25-45fa-a138-92aaf14543a8")}catch{}})();const oa=d({__name:"Project",setup(o){const c=g().params.projectId,{result:a}=h(()=>y.get(c).then(async e=>{const t=await z.get(e.organizationId);return{project:e,organization:t}})),l=m(()=>{var e,t,n,p;return((e=a.value)==null?void 0:e.organization)&&a.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(t=a.value)==null?void 0:t.organization)==null?void 0:n.name,path:`/organizations/${(p=a.value)==null?void 0:p.organization.id}`},{label:a.value.project.name,path:`/projects/${a.value.project.id}`}]:void 0}),u=m(()=>{var e;return(e=a.value)!=null&&e.project?[{name:"Project",items:[{name:"Builds",path:"builds",icon:w},{name:"Connectors",path:"connectors",icon:B},{name:"Tables",path:"tables",icon:k},{name:"API Keys",path:"api-keys",icon:C},{name:"Env Vars",path:"env-vars",icon:P},{name:"Files",path:"files",icon:$},{name:"Logs",icon:x,path:"logs",beta:!0},{name:"Settings",icon:D,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:M,path:`/organizations/${a.value.project.organizationId}/projects`},{name:"Members",icon:O,path:`/organizations/${a.value.project.organizationId}/members`},{name:"Billing",icon:S,path:`/organizations/${a.value.project.organizationId}/billing`,unavailable:!0}]}]:[]});return(e,t)=>{const n=b("router-view");return f(),v(_,null,{content:i(()=>[s(n)]),navbar:i(()=>[s(j,{class:"nav",breadcrumb:l.value},null,8,["breadcrumb"])]),sidebar:i(()=>[s(I,{class:"sidebar",sections:u.value},null,8,["sections"])]),_:1})}}});export{oa as default};
//# sourceMappingURL=Project.b928fca1.js.map
