import{S as p}from"./Sidebar.9ff7a5b4.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.056998e5.js";import{u as d,v as l,x as u}from"./icons.49e74e71.js";import{d as b,eB as f,G as g,a as _,b as y,c as v,w as t,f as r}from"./outputWidgets.c4f3de67.js";import{a as w}from"./asyncComputed.c75b06d6.js";import"./router.88734ca5.js";import{O as z}from"./organization.73e64f9c.js";import"./columns.aa61756c.js";import{B as h}from"./BaseLayout.3a885926.js";import"./Tooltip.48f63d67.js";import"./logo.084e5d7c.js";import"./index.205feec3.js";import"./transButton.ebe60b80.js";import"./Text.fcf8f28f.js";import"./Base.9ed9c296.js";import"./Title.345a4775.js";import"./index.db3809d7.js";import"./gateway.5578a098.js";import"./record.685c8ba7.js";import"./pubsub.1842fa2d.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="f213d578-533b-47d9-8609-43d0aff6869c",o._sentryDebugIdIdentifier="sentry-dbid-f213d578-533b-47d9-8609-43d0aff6869c")}catch{}})();const J=b({__name:"Organization",setup(o){const n=f().params.organizationId,{result:a}=w(()=>z.get(n)),i=g(()=>a.value?[{label:"My organizations",path:"/organizations"},{label:a.value.name,path:`/organizations/${a.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:t(()=>[r(c,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(p,{class:"sidebar",sections:s})]),content:t(()=>[r(m)]),_:1})}}});export{J as default};
//# sourceMappingURL=Organization.417dff4c.js.map
