import"./outputWidgets.c4f3de67.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="3c9b37ce-c978-47f7-bc12-2064aaf3ec9c",e._sentryDebugIdIdentifier="sentry-dbid-3c9b37ce-c978-47f7-bc12-2064aaf3ec9c")}catch{}})();function s(e){return e.charAt(0).toUpperCase()+e.slice(1)}function a(e,r){const n=e.toLocaleLowerCase().replace(/[^a-z0-9]/g,"_").replace(/_+/g,"_");return r?n:n.replace(/_$/,"")}export{s as c,a as n};
//# sourceMappingURL=string.f2726d1b.js.map
