import{F as I,r as R,g as B,R as P}from"./FormRunner.3954ded9.js";import{d as q,eB as x,eA as F,F as D,H as d,G as y,u as p,b as s,eu as u,f as E,c as S,eE as K,eF as L,e as c,t as N}from"./outputWidgets.c4f3de67.js";import{u as h}from"./uuid.bc546958.js";import{a as A}from"./asyncComputed.c75b06d6.js";import{L as C}from"./CircularLoading.ec6d04ea.js";import"./url.d2782274.js";import"./index.59f56925.js";import"./pubsub.1842fa2d.js";import"./icons.49e74e71.js";import"./PlayerNavbar.6f68c72f.js";import"./ActionButton.vue_vue_type_script_setup_true_lang.0800a950.js";import"./WidgetsFrame.d8c435df.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="006b9835-66ab-488e-9b8e-ab006f265d32",o._sentryDebugIdIdentifier="sentry-dbid-006b9835-66ab-488e-9b8e-ab006f265d32")}catch{}})();const l=o=>(K("data-v-1e2a2c24"),o=o(),L(),o),T={key:0,class:"loading"},V={key:1,class:"error"},G=l(()=>c("h1",null,"Oops! Something went wrong",-1)),H=l(()=>c("p",null,"An unknown error ocurred. Please try again or contact support.",-1)),O=[G,H],j={key:2,class:"form"},z={key:3,class:"error not-found"},J=l(()=>c("h1",null,"Page not found",-1)),M=l(()=>c("p",null,"The page you requested could not be found.",-1)),Q=[J,M],U=q({__name:"Player",setup(o){const t=x(),i=F(),_=D({playerKey:h()});d(t,()=>w());function v(e,a){R("player",i,e,a)}const b=({path:e})=>{i.push({name:"player",query:t.query,params:{path:e.split("/")}})},f=async()=>{_.playerKey=h()};d([()=>t.path,()=>t.query],()=>f());const{loading:g,result:r,error:k,refetch:w}=A(()=>{var e;return B((e=t.path.slice(1))!=null?e:"")}),m=y(()=>n.value?P.create(n.value.id):null),n=y(()=>{var e,a;return(a=(e=r.value)==null?void 0:e.form)!=null?a:null});return d(r,()=>{var e;!r.value||r.value.form&&(document.title=(e=r.value.form.welcomeTitle)!=null?e:r.value.form.title)}),(e,a)=>p(g)?(s(),u("div",T,[E(C)])):p(k)?(s(),u("div",V,O)):n.value&&m.value?(s(),u("div",j,[(s(),S(I,{key:_.playerKey,class:"player",form:n.value,"is-preview":!1,params:p(t).query,broker:m.value,"enable-auto-focus":!0,onNavigate:b,onLogout:f,onRedirect:v},null,8,["form","params","broker"]))])):(s(),u("div",z,Q))}});const ue=N(U,[["__scopeId","data-v-1e2a2c24"]]);export{ue as default};
//# sourceMappingURL=Player.52d71fcb.js.map
