import{cz as n}from"./outputWidgets.c4f3de67.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="e3158a9b-a70f-4081-8037-589c4233a0da",e._sentryDebugIdIdentifier="sentry-dbid-e3158a9b-a70f-4081-8037-589c4233a0da")}catch{}})();const d=(e,r)=>{n.error({message:e,description:r})};export{d as p};
//# sourceMappingURL=popupNotifcation.301aa26f.js.map
