import"./outputWidgets.c4f3de67.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="a1d09ec1-45f6-45d5-9aa9-122ecbbbbafd",e._sentryDebugIdIdentifier="sentry-dbid-a1d09ec1-45f6-45d5-9aa9-122ecbbbbafd")}catch{}})();function f(e,a){const d=document,i=e.matched.slice().reverse().find(t=>t.meta&&t.meta.title),n=a.matched.slice().reverse().find(t=>t.meta&&t.meta.metaTags);i?d.title=i.meta.title:n&&(d.title=n.meta.title)}export{f as u};
//# sourceMappingURL=index.db3809d7.js.map
