import{t as o,a as i,b as a,c,i as d,T as p,j as u,P as _,C as l,M as f,s as g,k as s,l as m,m as b,n as y,p as v}from"./outputWidgets.c4f3de67.js";import{u as w,s as h,a as r}from"./index.59f56925.js";import"./pubsub.1842fa2d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="30e8e164-a92d-46b6-8064-e4cd7dbce208",e._sentryDebugIdIdentifier="sentry-dbid-30e8e164-a92d-46b6-8064-e4cd7dbce208")}catch{}})();const I={};function k(e,t){const n=i("router-view");return a(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const x=o(I,[["render",k]]);class P{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await Promise.all([w(),h()]);const e=d({render:()=>m(x)});p.init(),u(e,r),P.init(),e.use(r),e.use(_),e.mount("#app"),e.component("VSelect",l),e.component("Markdown",f),e.component("Message",g),s(e,b),s(e,y),s(e,v)})();
//# sourceMappingURL=player.5f3dde59.js.map
