.auth-info[data-v-06bca615]{display:flex;flex-direction:column;text-align:center}.auth-info .text-small[data-v-06bca615]{max-width:400px}.auth-info path[data-v-06bca615]{fill:var(--font-color)}.auth-info .auth-header[data-v-06bca615]{display:flex;flex-direction:column;margin-bottom:30px;align-items:flex-start}.auth-info .auth-header .icon[data-v-06bca615]{grid-area:icon;height:1.5rem;margin:auto}.auth-info .auth-header .auth-label[data-v-06bca615]{grid-area:label;font-size:1.25rem;margin-bottom:10px;font-weight:700}.auth-info .auth-header .description[data-v-06bca615]{grid-area:desc;font-size:1rem;font-weight:500}.auth-info .input[data-v-06bca615]{padding:12px!important}.auth-info .spacer[data-v-06bca615]{height:0px;width:100%;border-bottom:1px solid #dbdee4;margin:40px 0}.auth-info .next-button[data-v-06bca615]{margin-bottom:35px}.auth-info .support-link[data-v-06bca615]{text-decoration:none;color:var(--color-main)}.auth-info .footer[data-v-06bca615]{font-size:14px;margin:unset}.workspace-auth .auth-header[data-v-06bca615]{align-items:center}.workspace-auth .next-button[data-v-06bca615]{width:100%}.span-error[data-v-06bca615]{font-size:14px;color:red;padding-top:8px;background:transparent;border-radius:8px;max-width:220px;white-space:pre-wrap;align-self:flex-start}.auth-token[data-v-894be184]{display:flex;flex-direction:column;text-align:center;align-items:flex-start}.auth-token .auth-label[data-v-894be184]{font-size:16px;margin-bottom:30px}.auth-token .text-small[data-v-894be184]{max-width:400px}.auth-token path[data-v-894be184]{fill:var(--font-color)}.auth-token .input[data-v-894be184]{padding:12px!important}.auth-token .spacer[data-v-894be184]{height:0px;width:100%;border-bottom:1px solid #dbdee4;margin:40px 0}.auth-token .next-button[data-v-894be184]{width:100%;margin-bottom:20px}.auth-token .back[data-v-894be184]{margin-bottom:20px;font-size:16px;width:100%;display:flex;align-items:center;justify-content:center;gap:15px}.auth-token .footer[data-v-894be184]{font-size:14px;margin-top:15px;text-align:left}.auth-token .button-icon[data-v-894be184]{width:25px;height:25px;fill:#fff;display:flex;align-items:center;justify-content:center}.span-error[data-v-894be184]{font-size:14px;color:red;padding-top:8px;background:transparent;border-radius:8px;max-width:220px;white-space:pre-wrap;max-width:unset}[data-v-6b5a711a]:root{--main-font-family: DM Sans, sans-serif}[data-v-6b5a711a]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-6b5a711a]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-6b5a711a]{background-color:#fff;padding:10px}.form[data-v-6b5a711a]{padding:2rem 0}.widget[data-v-6b5a711a]{position:relative}.loading[data-v-6b5a711a]{display:flex;justify-content:center}.login[data-v-c3f079b3]{display:flex;align-items:center;justify-content:center;height:100vh}
