import{ee as p,ab as f,U as s,f as b,O as y}from"./outputWidgets.c4f3de67.js";import{B as d,a as u}from"./Base.9ed9c296.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="05be525a-16e6-46a6-b9a1-4963c5a9e8c8",e._sentryDebugIdIdentifier="sentry-dbid-05be525a-16e6-46a6-b9a1-4963c5a9e8c8")}catch{}})();var g=globalThis&&globalThis.__rest||function(e,o){var n={};for(var t in e)Object.prototype.hasOwnProperty.call(e,t)&&o.indexOf(t)<0&&(n[t]=e[t]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var r=0,t=Object.getOwnPropertySymbols(e);r<t.length;r++)o.indexOf(t[r])<0&&Object.prototype.propertyIsEnumerable.call(e,t[r])&&(n[t[r]]=e[t[r]]);return n};const m=p(1,2,3,4,5),_=()=>s(s({},y(u(),["component","strong"])),{level:Number}),a=(e,o)=>{let{slots:n,attrs:t}=o;const{level:r=1}=e,i=g(e,["level"]);let l;m.includes(r)?l=`h${r}`:(f(),l="h1");const c=s(s(s({},i),{component:l}),t);return b(d,c,n)};a.displayName="ATypographyTitle";a.inheritAttrs=!1;a.props=_();const T=a;export{T as A};
//# sourceMappingURL=Title.345a4775.js.map
