import{t,b as s,eu as a}from"./outputWidgets.c4f3de67.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="b12642bc-cb49-482a-ade4-6a7e5db9615a",e._sentryDebugIdIdentifier="sentry-dbid-b12642bc-cb49-482a-ade4-6a7e5db9615a")}catch{}})();const o={},r={class:"organization-settings"};function d(e,n){return s(),a("div",r,"Organization settings")}const b=t(o,[["render",d]]);export{b as default};
//# sourceMappingURL=OrganizationSettings.fce8597d.js.map
