import{_ as B}from"./logo.084e5d7c.js";import{t as C,b as r,eu as y,eE as I,eF as w,e as h,d as k,eA as L,a as D,u as e,c,bu as S,w as t,f as o,aq as l,eD as i,bU as f,cF as b,cB as N,eH as V,eC as E,eZ as F,a_ as R,ew as T}from"./outputWidgets.c4f3de67.js";import{a as g}from"./router.88734ca5.js";import{a as H}from"./asyncComputed.c75b06d6.js";import{A as P,B as U,a as $,c as j}from"./index.205feec3.js";import{c as q}from"./Text.fcf8f28f.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[s]="9a63c8d0-d5e1-49e3-a375-20b634e7b33c",a._sentryDebugIdIdentifier="sentry-dbid-9a63c8d0-d5e1-49e3-a375-20b634e7b33c")}catch{}})();const M={},v=a=>(I("data-v-439be421"),a=a(),w(),a),Z={class:"logo"},z=v(()=>h("img",{class:"logo-img",src:B,alt:"Abstra cloud logo"},null,-1)),G=v(()=>h("span",null,"Abstra Cloud",-1)),J=[z,G];function K(a,s){return r(),y("div",Z,J)}const O=C(M,[["render",K],["__scopeId","data-v-439be421"]]),Q=k({__name:"LoginBlock",setup(a){function s(p){const m=p.split("@")[0];return V.exports.kebabCase(m).toUpperCase().split("-").slice(0,2).map(_=>_[0]).join("")}const u=L(),{result:n,loading:d,refetch:A}=H(async()=>g.getAuthor());function x(){g.removeAuthor(),A(),u.push({name:"login"})}return(p,m)=>{const _=D("router-link");return e(d)?(r(),c(e(S),{key:0})):e(n)?(r(),c(e(N),{key:1,placement:"bottomRight"},{content:t(()=>[o(e(b),{direction:"vertical"},{default:t(()=>[o(e(q),null,{default:t(()=>[l(i(e(n).claims.email),1)]),_:1}),o(e(f),{onClick:x},{default:t(()=>[l("Logout")]),_:1})]),_:1})]),default:t(()=>[o(e(b),{align:"center",style:{cursor:"pointer"}},{default:t(()=>[o(e(P),null,{default:t(()=>[l(i(s(e(n).claims.email)),1)]),_:1})]),_:1})]),_:1})):(r(),c(e(f),{key:2},{default:t(()=>[o(_,{to:"/login"},{default:t(()=>[l("Login")]),_:1})]),_:1}))}}}),oe=k({__name:"Navbar",props:{breadcrumb:{}},setup(a){return(s,u)=>(r(),c(e(j),{style:{padding:"5px 10px"}},{breadcrumb:t(()=>[s.breadcrumb?(r(),c(e(U),{key:0},{default:t(()=>[(r(!0),y(R,null,E(s.breadcrumb,(n,d)=>(r(),c(e($),{key:d},{default:t(()=>[o(e(F),{to:n.path},{default:t(()=>[l(i(n.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):T("",!0)]),title:t(()=>[o(O)]),extra:t(()=>[o(Q)]),_:1}))}});export{oe as _};
//# sourceMappingURL=Navbar.vue_vue_type_script_setup_true_lang.056998e5.js.map
