import"./outputWidgets.c4f3de67.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="614e29db-fdb0-4194-b5d5-003eeea36293",e._sentryDebugIdIdentifier="sentry-dbid-614e29db-fdb0-4194-b5d5-003eeea36293")}catch{}})();const r=e=>{try{return new URL(e),!0}catch{return!1}};export{r as i};
//# sourceMappingURL=url.d2782274.js.map
